@@ -22,11 +22,8 @@ from calculate.install.distr import IsoDistributive, DistributiveError
 from calculate.lib.utils.files import listDirectory
 from calculate.lib.datavars import ReadonlyVariable, HumanReadable, \
     ReadonlyTableVariable, FieldValue, VariableError, Variable
-from calculate.install.variables.system import VariableOsInstallX11ServerSet
-from builder import (VariableClBuilderPath, VariableClBuilderKernel,
-                     VariableClBuilderKernelVer, VariableClBuilderInitrdInstall,
-                     VariableClBuilderVideoDriverPath,
-                     VariableClBuilderVideodrvSet)
+from calculate.install.variables import system
+import builder
 from action import Actions
 
 _ = lambda x: x
@@ -74,14 +71,14 @@ class DataVarsBuilderImage(LinuxDataVars):
     def variables(self):
         l = super(DataVarsBuilderImage, self).variables()
         return l + [
-            VariableClBuilderPath(),
-            VariableClBuilderKernel(),
-            VariableClBuilderInitrdInstall(),
-            VariableClBuilderKernelVer(),
-            VariableOsInstallX11ServerSet(image=False,
+            builder.VariableClBuilderPath(),
+            builder.VariableClBuilderKernel(),
+            builder.VariableClBuilderInitrdInstall(),
+            builder.VariableClBuilderKernelVer(),
+            system.VariableOsInstallX11ServerSet(image=False,
                                           prefix_variable="cl_builder_path"),
-            VariableClBuilderVideoDriverPath(),
-            VariableClBuilderVideodrvSet(autodetect=True),
+            builder.VariableClBuilderVideoDriverPath(),
+            builder.VariableClBuilderVideodrvSet(autodetect=True),
             VariableClBuilderIsoLabel(),
             VariableClBuilderSplash(),
         ]
@@ -168,7 +165,7 @@ class VariableClBuilderImageData(ReadonlyTableVariable):
                 pass
 
     def get(self, hr=HumanReadable.No):
-        isopath = self.Get('cl_builder_flash_repository')
+        isopath = self.Get('cl_builder_image_repository')
         if self.Get('cl_builder_action') != Actions.ImageMenu or not isopath:
             return [[]]
         return list(self.generator(isopath))
